==> qtjambi-scxml-6.2.2-sources.jar: io/qt/scxml/QScxmlTableData.java <==
package io.qt.scxml;


/**
 * <p>Used by compiled state machines</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qscxmltabledata.html">QScxmlTableData</a></p>
 */
public interface QScxmlTableData extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.scxml.QScxmlTableData}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.scxml.QScxmlTableData
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QScxmlTableData.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.scxml.QScxmlExecutableContent.AssignmentInfo assignmentInfo(int assignmentId){
                return assignmentInfo_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), assignmentId);
            }
            private native static io.qt.scxml.QScxmlExecutableContent.AssignmentInfo assignmentInfo_native_int_constfct(long __this__nativeId, int assignmentId);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.nio.IntBuffer dataNames(){
                return dataNames_native_int_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.nio.IntBuffer dataNames_native_int_ptr_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.scxml.QScxmlExecutableContent.EvaluatorInfo evaluatorInfo(int evaluatorId){
                return evaluatorInfo_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), evaluatorId);
            }
            private native static io.qt.scxml.QScxmlExecutableContent.EvaluatorInfo evaluatorInfo_native_int_constfct(long __this__nativeId, int evaluatorId);
            
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.scxml.QScxmlExecutableContent.ForeachInfo foreachInfo(int foreachId){
                return foreachInfo_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), foreachId);
            }
            private native static io.qt.scxml.QScxmlExecutableContent.ForeachInfo foreachInfo_native_int_constfct(long __this__nativeId, int foreachId);
            
            
            @Override
            @io.qt.QtUninvokable
            public int initialSetup(){
                return initialSetup_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static int initialSetup_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.nio.IntBuffer instructions(){
                return instructions_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.nio.IntBuffer instructions_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String name(){
                return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String name_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.scxml.QScxmlInvokableServiceFactory serviceFactory(int id){
                return serviceFactory_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), id);
            }
            private native static io.qt.scxml.QScxmlInvokableServiceFactory serviceFactory_native_int_constfct(long __this__nativeId, int id);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.nio.IntBuffer stateMachineTable(){
                return stateMachineTable_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.nio.IntBuffer stateMachineTable_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String string(int id){
                return string_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), id);
            }
            private native static java.lang.String string_native_int_constfct(long __this__nativeId, int id);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QScxmlTableData instance);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#assignmentInfo">QScxmlTableData::assignmentInfo(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.scxml.QScxmlExecutableContent.AssignmentInfo assignmentInfo(int assignmentId);
        
        private native static io.qt.scxml.QScxmlExecutableContent.AssignmentInfo assignmentInfo_native_int_constfct(long __this__nativeId, int assignmentId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#dataNames">QScxmlTableData::dataNames(int*)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.nio.IntBuffer dataNames();
        
        private native static java.nio.IntBuffer dataNames_native_int_ptr_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#evaluatorInfo">QScxmlTableData::evaluatorInfo(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.scxml.QScxmlExecutableContent.EvaluatorInfo evaluatorInfo(int evaluatorId);
        
        private native static io.qt.scxml.QScxmlExecutableContent.EvaluatorInfo evaluatorInfo_native_int_constfct(long __this__nativeId, int evaluatorId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#foreachInfo">QScxmlTableData::foreachInfo(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.scxml.QScxmlExecutableContent.ForeachInfo foreachInfo(int foreachId);
        
        private native static io.qt.scxml.QScxmlExecutableContent.ForeachInfo foreachInfo_native_int_constfct(long __this__nativeId, int foreachId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#initialSetup">QScxmlTableData::initialSetup()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract int initialSetup();
        
        private native static int initialSetup_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#instructions">QScxmlTableData::instructions()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.nio.IntBuffer instructions();
        
        private native static java.nio.IntBuffer instructions_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#name">QScxmlTableData::name()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String name();
        
        private native static java.lang.String name_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#serviceFactory">QScxmlTableData::serviceFactory(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.scxml.QScxmlInvokableServiceFactory serviceFactory(int id);
        
        private native static io.qt.scxml.QScxmlInvokableServiceFactory serviceFactory_native_int_constfct(long __this__nativeId, int id);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#stateMachineTable">QScxmlTableData::stateMachineTable()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.nio.IntBuffer stateMachineTable();
        
        private native static java.nio.IntBuffer stateMachineTable_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#string">QScxmlTableData::string(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String string(int id);
        
        private native static java.lang.String string_native_int_constfct(long __this__nativeId, int id);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#assignmentInfo">QScxmlTableData::assignmentInfo(QScxmlExecutableContent::EvaluatorId)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.scxml.QScxmlExecutableContent.AssignmentInfo assignmentInfo(int assignmentId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#dataNames">QScxmlTableData::dataNames(int*)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.nio.IntBuffer dataNames();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#evaluatorInfo">QScxmlTableData::evaluatorInfo(QScxmlExecutableContent::EvaluatorId)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.scxml.QScxmlExecutableContent.EvaluatorInfo evaluatorInfo(int evaluatorId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#foreachInfo">QScxmlTableData::foreachInfo(QScxmlExecutableContent::EvaluatorId)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.scxml.QScxmlExecutableContent.ForeachInfo foreachInfo(int foreachId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#initialSetup">QScxmlTableData::initialSetup()const</a></p>
     */
    @io.qt.QtUninvokable
    public int initialSetup();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#instructions">QScxmlTableData::instructions()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.nio.IntBuffer instructions();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#name">QScxmlTableData::name()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String name();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#serviceFactory">QScxmlTableData::serviceFactory(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.scxml.QScxmlInvokableServiceFactory serviceFactory(int id);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#stateMachineTable">QScxmlTableData::stateMachineTable()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.nio.IntBuffer stateMachineTable();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#string">QScxmlTableData::string(QScxmlExecutableContent::StringId)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String string(int id);
    
}

==> qtjambi-scxml-6.4.0-sources.jar: io/qt/scxml/QScxmlTableData.java <==
package io.qt.scxml;


/**
 * <p>Used by compiled state machines</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qscxmltabledata.html">QScxmlTableData</a></p>
 */
public interface QScxmlTableData extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.scxml.QScxmlTableData}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.scxml.QScxmlTableData
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QScxmlTableData.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.scxml.QScxmlExecutableContent.AssignmentInfo assignmentInfo(int assignmentId){
                return assignmentInfo_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), assignmentId);
            }
            private native static io.qt.scxml.QScxmlExecutableContent.AssignmentInfo assignmentInfo_native_int_constfct(long __this__nativeId, int assignmentId);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.nio.IntBuffer dataNames(){
                return dataNames_native_int_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.nio.IntBuffer dataNames_native_int_ptr_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.scxml.QScxmlExecutableContent.EvaluatorInfo evaluatorInfo(int evaluatorId){
                return evaluatorInfo_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), evaluatorId);
            }
            private native static io.qt.scxml.QScxmlExecutableContent.EvaluatorInfo evaluatorInfo_native_int_constfct(long __this__nativeId, int evaluatorId);
            
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.scxml.QScxmlExecutableContent.ForeachInfo foreachInfo(int foreachId){
                return foreachInfo_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), foreachId);
            }
            private native static io.qt.scxml.QScxmlExecutableContent.ForeachInfo foreachInfo_native_int_constfct(long __this__nativeId, int foreachId);
            
            
            @Override
            @io.qt.QtUninvokable
            public int initialSetup(){
                return initialSetup_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static int initialSetup_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.nio.IntBuffer instructions(){
                return instructions_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.nio.IntBuffer instructions_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String name(){
                return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String name_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.scxml.QScxmlInvokableServiceFactory serviceFactory(int id){
                return serviceFactory_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), id);
            }
            private native static io.qt.scxml.QScxmlInvokableServiceFactory serviceFactory_native_int_constfct(long __this__nativeId, int id);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.nio.IntBuffer stateMachineTable(){
                return stateMachineTable_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.nio.IntBuffer stateMachineTable_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String string(int id){
                return string_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), id);
            }
            private native static java.lang.String string_native_int_constfct(long __this__nativeId, int id);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QScxmlTableData instance);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#assignmentInfo">QScxmlTableData::assignmentInfo(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.scxml.QScxmlExecutableContent.AssignmentInfo assignmentInfo(int assignmentId);
        
        private native static io.qt.scxml.QScxmlExecutableContent.AssignmentInfo assignmentInfo_native_int_constfct(long __this__nativeId, int assignmentId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#dataNames">QScxmlTableData::dataNames(int*)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.nio.IntBuffer dataNames();
        
        private native static java.nio.IntBuffer dataNames_native_int_ptr_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#evaluatorInfo">QScxmlTableData::evaluatorInfo(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.scxml.QScxmlExecutableContent.EvaluatorInfo evaluatorInfo(int evaluatorId);
        
        private native static io.qt.scxml.QScxmlExecutableContent.EvaluatorInfo evaluatorInfo_native_int_constfct(long __this__nativeId, int evaluatorId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#foreachInfo">QScxmlTableData::foreachInfo(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.scxml.QScxmlExecutableContent.ForeachInfo foreachInfo(int foreachId);
        
        private native static io.qt.scxml.QScxmlExecutableContent.ForeachInfo foreachInfo_native_int_constfct(long __this__nativeId, int foreachId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#initialSetup">QScxmlTableData::initialSetup()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract int initialSetup();
        
        private native static int initialSetup_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#instructions">QScxmlTableData::instructions()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.nio.IntBuffer instructions();
        
        private native static java.nio.IntBuffer instructions_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#name">QScxmlTableData::name()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String name();
        
        private native static java.lang.String name_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#serviceFactory">QScxmlTableData::serviceFactory(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.scxml.QScxmlInvokableServiceFactory serviceFactory(int id);
        
        private native static io.qt.scxml.QScxmlInvokableServiceFactory serviceFactory_native_int_constfct(long __this__nativeId, int id);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#stateMachineTable">QScxmlTableData::stateMachineTable()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.nio.IntBuffer stateMachineTable();
        
        private native static java.nio.IntBuffer stateMachineTable_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#string">QScxmlTableData::string(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String string(int id);
        
        private native static java.lang.String string_native_int_constfct(long __this__nativeId, int id);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#assignmentInfo">QScxmlTableData::assignmentInfo(QScxmlExecutableContent::EvaluatorId)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.scxml.QScxmlExecutableContent.AssignmentInfo assignmentInfo(int assignmentId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#dataNames">QScxmlTableData::dataNames(int*)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.nio.IntBuffer dataNames();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#evaluatorInfo">QScxmlTableData::evaluatorInfo(QScxmlExecutableContent::EvaluatorId)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.scxml.QScxmlExecutableContent.EvaluatorInfo evaluatorInfo(int evaluatorId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#foreachInfo">QScxmlTableData::foreachInfo(QScxmlExecutableContent::EvaluatorId)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.scxml.QScxmlExecutableContent.ForeachInfo foreachInfo(int foreachId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#initialSetup">QScxmlTableData::initialSetup()const</a></p>
     */
    @io.qt.QtUninvokable
    public int initialSetup();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#instructions">QScxmlTableData::instructions()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.nio.IntBuffer instructions();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#name">QScxmlTableData::name()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String name();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#serviceFactory">QScxmlTableData::serviceFactory(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.scxml.QScxmlInvokableServiceFactory serviceFactory(int id);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#stateMachineTable">QScxmlTableData::stateMachineTable()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.nio.IntBuffer stateMachineTable();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmltabledata.html#string">QScxmlTableData::string(QScxmlExecutableContent::StringId)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String string(int id);
    
}
